==> r14.0.8.zip: ksystemlog/ksystemlog/src/acpid/acpidOptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

//TQt includes
#include <tqlayout.h>
#include <tqvgroupbox.h>
#include <tqbuttongroup.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqvbox.h>
#include <tqhbox.h>

//KDE includes
#include <tdelocale.h>
#include <tdeactioncollection.h>
#include <kbuttonbox.h>
#include <tdelistbox.h>
#include <tdefiledialog.h>
#include <kurl.h>
#include <tdemessagebox.h>
#include <kiconloader.h>
#include <kdebug.h>

//Project includes
#include "acpidOptions.h"
#include "ksystemlogConfig.h"

AcpidOptions::AcpidOptions(TQWidget *parent) : 
	TQWidget(parent) 
	{
	
	TQHBoxLayout *layout = new TQHBoxLayout(this);
	layout->setAutoAdd(true);

	TQString description=i18n("<qt><p>These files will be analyzed to display <b>ACPId log</b>. This list also determines the order in which the files are read.</p></qt>");
	fileList=new FileList(this, description);
	
	connect(fileList, TQT_SIGNAL(fileListChanged(int)), this, TQT_SLOT(slotFileListChanged(int)));
	
	readConfig();
	

}

AcpidOptions::~AcpidOptions() {
	//TODO Delete fileList (and also in other *Options classes)
}

bool AcpidOptions::isValid() {
	if (fileList->count()>0)
		return(true);
	else
		return(false);
}

void AcpidOptions::slotFileListChanged(int itemLeft) {
	if (itemLeft==0)
		emit optionsChanged(false);
	else
		emit optionsChanged(true);
}

void AcpidOptions::saveConfig() {
	kdDebug() << "Save config from AcpidOptions" << endl;
	
	TQStringList list;
	
	int count=fileList->count();
	
	for (int i=0; i<count; i++) {
		list.push_back(fileList->getText(i));
	}
	
	KSystemLogConfig::setAcpidPaths(list);
}

void AcpidOptions::readConfig() {
	TQStringList files(KSystemLogConfig::acpidPaths());
		
	TQStringList::iterator it;
	for(it=files.begin(); it!=files.end(); ++it) {
		fileList->insertItem(*it);
	}

}

#include "acpidOptions.moc"

==> r14.1.2.zip: ksystemlog/ksystemlog/src/acpid/acpidOptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

//TQt includes
#include <tqlayout.h>
#include <tqvgroupbox.h>
#include <tqbuttongroup.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqvbox.h>
#include <tqhbox.h>

//KDE includes
#include <tdelocale.h>
#include <tdeactioncollection.h>
#include <kbuttonbox.h>
#include <tdelistbox.h>
#include <tdefiledialog.h>
#include <kurl.h>
#include <tdemessagebox.h>
#include <kiconloader.h>
#include <kdebug.h>

//Project includes
#include "acpidOptions.h"
#include "ksystemlogConfig.h"

AcpidOptions::AcpidOptions(TQWidget *parent) : 
	TQWidget(parent) 
	{
	
	TQHBoxLayout *layout = new TQHBoxLayout(this);
	layout->setAutoAdd(true);

	TQString description=i18n("<qt><p>These files will be analyzed to display <b>ACPId log</b>. This list also determines the order in which the files are read.</p></qt>");
	fileList=new FileList(this, description);
	
	connect(fileList, TQ_SIGNAL(fileListChanged(int)), this, TQ_SLOT(slotFileListChanged(int)));
	
	readConfig();
	

}

AcpidOptions::~AcpidOptions() {
	//TODO Delete fileList (and also in other *Options classes)
}

bool AcpidOptions::isValid() {
	if (fileList->count()>0)
		return(true);
	else
		return(false);
}

void AcpidOptions::slotFileListChanged(int itemLeft) {
	if (itemLeft==0)
		emit optionsChanged(false);
	else
		emit optionsChanged(true);
}

void AcpidOptions::saveConfig() {
	kdDebug() << "Save config from AcpidOptions" << endl;
	
	TQStringList list;
	
	int count=fileList->count();
	
	for (int i=0; i<count; i++) {
		list.push_back(fileList->getText(i));
	}
	
	KSystemLogConfig::setAcpidPaths(list);
}

void AcpidOptions::readConfig() {
	TQStringList files(KSystemLogConfig::acpidPaths());
		
	TQStringList::iterator it;
	for(it=files.begin(); it!=files.end(); ++it) {
		fileList->insertItem(*it);
	}

}

#include "acpidOptions.moc"
